#item QToolTip, QMenu QToolTip {
    ;${notes_font}
    ;background: ${notes_bg}
    ;color: ${notes_fg}
    /* Resetting border helps in some cases to set correct background color. */
    ;border: 1px solid ${notes_fg}
    ;${notes_css}
}
